/*
 * Copyright 2021-2025 Nico Sonack <nsonack@herrhotzenplotz.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef GCLI_CMD_GITCONFIG_H
#define GCLI_CMD_GITCONFIG_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

struct gcli_gitremote {
	char *name;
	char *owner;
	char *repo;
	char *url;
	gcli_forge_type forge_type;
};

gcli_sv gcli_gitconfig_get_current_branch(void);

void gcli_gitconfig_add_fork_remote(char const *org, char const *repo);

int gcli_gitconfig_get_forgetype(struct gcli_ctx *ctx, char const *remote_name);

int gcli_gitconfig_repo_by_remote(struct gcli_ctx *ctx, char const *const remote_name,
                                  char const **const owner, char const **const repo,
                                  int *const forge);

int gcli_gitconfig_get_remote(struct gcli_ctx *ctx, gcli_forge_type type,
                              char const **remote);

#endif /* GCLI_CMD_GITCONFIG_H */
